var EventEmitter = require('events').EventEmitter
var request = require('request')
var parser = require('xml2json')
var debug = require('debug')('feeder:feed')
var inherit = require('util').inherits

/**
 * Feed constructor
 * @param  {String} name name of the Feed, to identify it
 * @param  {String} link Link to the Feed
 */
function Feed (name, link, interval) {
  debug('called Feed constructor')

  EventEmitter.call(this)

  this.id = null
  this.name = name
  this.link = link
  this.watching = false
  this.interval = 30000
  this.header = null
  this.body = null
}

// inherit Eventemitter prototrype
inherit(Feed, EventEmitter)


Feed.prototype.request = function(cb) {
  request(this.link, function (err, header, body) {
    if (err) return cb(err)

    this.header = header
    this.body = parser.toJson(body, { object: true })

    return cb(null, this)
  })
}


Feed.prototype.watch = function(interval, cb) {
  if (! interval) {
    cb = interval
    interval = null
  } else {
    this.interval = interval
  }

  this.id = setInterval(this.request, this.interval, cb)
  this.watching = true
  return
}


Feed.prototype.stop = function() {
  if (this.watching) {
    debug('clearInterval on feed ')

    clearInterval(this.id)
    this.id = null
    this.watching = false
    return
  }

  return
}


/**
 * Factory method of Feed constructor
 * @param  {String} name name of the Feed, to identify it
 * @param  {String} link Link to the Feed
 * @param  {Object} app  Application object
 * @return {Object}      Returns a feed object
 */
function feed (name, link, app) {
  debug('called Feed Factory')

  if (app.feeds.has(name)) {
    return app.feeds.get(name)
  }

  var f = new Feed(name, link)
  app.feeds.set(name, f)

  return f
}


// expose public interface
exports.Feed = Feed
exports.feed = feed
