var expect = require('chai').expect
var Feed = require('../lib/feed').Feed

describe('Feed', function () {
  it('should exist', function () {
    expect(Feed).to.exist
  })
  it('should be defined', function () { expect(Feed).to.be.not.undefined })
  it('should be a function', function () { expect(Feed).to.be.a('function') })

  describe('.request', function () {
    it('should exist', function () {
      var f = new Feed('test', 'test')
      expect(f.request).to.exist
    })
    it('should be defined', function () {
      var f = new Feed('test', 'test')
      expect(f.request).to.be.not.undefined
    })
    it('should be a function', function () {
      var f = new Feed('test', 'test')
      expect(f.request).to.be.a('function')
    })
    it('should request the link', function () {
      var f = new Feed('test', 'https://github.com/luii/luftwaffle/commits/master.atom')
      f.request(function (err, success) {
        expect(success).to.be.ok
      })
    })
    it('should fail if the provided link is not valid', function () {
      var f = new Feed('test', 'https://github.com/lu/luftwaffle/commits/master.atom')
      f.request(function (err, success) {
        expect(err).to.be.instanceof(Error)
        expect(success).to.be.false

      })
    })
  })

  describe('.watch', function () {
    it('should exist', function () {
      var f = new Feed('test', 'test')
      expect(f.watch).to.exist
    })
    it('should be defined', function () {
      var f = new Feed('test', 'test')
      expect(f.watch).to.be.not.undefined
    })
    it('should be a function', function () {
      var f = new Feed('test', 'test')
      expect(f.watch).to.be.a('function')
    })
  })

  describe('.stop', function () {
    it('should exist', function () {
      var f = new Feed('test', 'test')
      expect(f.stop).to.exist
    })
    it('should be defined', function () {
      var f = new Feed('test', 'test')
      expect(f.stop).to.be.not.undefined
    })
    it('should be a function', function () {
      var f = new Feed('test', 'test')
      expect(f.stop).to.be.a('function')
    })
    it('should stop the interval and set the id to null', function () {
      var f = new Feed('test', 'test')
      f.watch(30000, function (err, feed) {
        expect(err).to.be.null
        expect(f).to.equal(feed)
      })
      f.stop()

      expect(f.id).to.be.null
    })
  });

  describe('.on', function () {
    it('should exist', function () {
      var f = new Feed('test', 'test')
      expect(f.on).to.exist
    })
    it('should be defined', function () {
      var f = new Feed('test', 'test')
      expect(f.on).to.be.not.undefined
    })
    it('should be a function', function () {
      var f = new Feed('test', 'test')
      expect(f.on).to.be.a('function')
    })
  })

  describe('.once', function () {
    it('should exist', function () {
      var f = new Feed('test', 'test')
      expect(f.once).to.exist
    })
    it('should be defined', function () {
      var f = new Feed('test', 'test')
      expect(f.once).to.be.not.undefined
    })
    it('should be a function', function () {
      var f = new Feed('test', 'test')
      expect(f.once).to.be.a('function')
    })
  })

  describe('.emit', function () {
    it('should exist', function () {
      var f = new Feed('test', 'test')
      expect(f.emit).to.exist
    })
    it('should be defined', function () {
      var f = new Feed('test', 'test')
      expect(f.emit).to.be.not.undefined
    })
    it('should be a function', function () {
      var f = new Feed('test', 'test')
      expect(f.emit).to.be.a('function')
    })
  })
})