var expect = require('chai').expect
var Feed = require('../lib/feed').Feed
var Feeder = require('../lib/feeder').Feeder

describe('Feeder', function () {
  it('should exist', function () {
    expect(Feeder).to.exist
  })
  it('should be defined', function () {
    expect(Feeder).to.be.not.undefined
  })
  it('should be a function', function () {
    expect(Feeder).to.be.a('function')
  })

  describe('.add', function () {
    it('should exist', function () {
      var feeder = new Feeder()
      expect(feeder.add).to.exist
    })
    it('should be defined', function () {
      var feeder = new Feeder()
      expect(feeder.add).to.be.not.undefined
    })
    it('should be a function', function () {
      var feeder = new Feeder()
      expect(feeder.add).to.be.a('function')
    })
    it('should add a new feed to the application', function () {
      var feeder = new Feeder()
      feeder.add('test', 'test')

      expect(feeder.feeds.has('test')).to.be.ok
    })
    it('should be a instance of Feed', function () {
      var feeder = new Feeder()
      feeder.add('test', 'test')

      expect(feeder.feeds.get('test')).to.be.instanceof(Feed)
    })
    it('should be the same name', function () {
      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')

      var feed = feeder.feeds.get('test')

      expect(feed.name).to.equal('test')
    })
    it('should be the same link', function () {
      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')

      var feed = feeder.feeds.get('test')

      expect(feed.link).to.equal('http://www.example.com/test.rss')
    })
    it('should have a default interval', function () {
      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')

      var feed = feeder.feeds.get('test')

      expect(feed.interval).to.equal(30000)
    })
  })

  describe('.watch', function () {
    it('should exist', function () {
      var feeder = new Feeder()
      expect(feeder.watch).to.exist
    })
    it('should be defined', function () {
      var feeder = new Feeder()
      expect(feeder.watch).to.be.not.undefined
    })
    it('should be a function', function () {
      var feeder = new Feeder()
      expect(feeder.watch).to.be.a('function')
    })
    it('should have a timer object', function () {
      var feed
      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')

      feeder.watch('test')


      feed = feeder.feeds.get('test')
      expect(feed.id).to.be.a('object')
    })
  })

  describe('.watchAll', function () {
    it('should exist', function () {
      var feeder = new Feeder()
      expect(feeder.watchAll).to.exist
    })
    it('should be defined', function () {
      var feeder = new Feeder()
      expect(feeder.watchAll).to.be.not.undefined
    })
    it('should be a function', function () {
      var feeder = new Feeder()
      expect(feeder.watchAll).to.be.a('function')
    })
    it('should have a timer object', function () {
      var feed
      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')

      feeder.watchAll()

      feed = feeder.feeds.get('test')
      expect(feed.id).to.be.a('object')
    })
  })

  describe('.stop', function () {
    it('should exist', function () {
      var feeder = new Feeder()
      expect(feeder.stop).to.exist
    })
    it('should be defined', function () {
      var feeder = new Feeder()
      expect(feeder.stop).to.be.not.undefined
    })
    it('should be a function', function () {
      var feeder = new Feeder()
      expect(feeder.stop).to.be.a('function')
    })
    it('should stop the timer and set the id back to null', function () {
      var feed
      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')

      feeder.watch('test')

      feeder.stop('test')
      expect(feeder.feeds.get('test').id).to.be.null
    })
  })

  describe('.stopAll', function () {
    it('should exist', function () {
      var feeder = new Feeder()
      expect(feeder.stopAll).to.exist
    })
    it('should be defined', function () {
      var feeder = new Feeder()
      expect(feeder.stopAll).to.be.not.undefined
    })
    it('should be a function', function () {
      var feeder = new Feeder()
      expect(feeder.stopAll).to.be.a('function')
    })
    it('should stop the timers and set the ids back to null', function () {

      var feeder = new Feeder()
      feeder.add('test', 'http://www.example.com/test.rss')
      feeder.add('test2', 'http://www.example.com/test.rss')

      feeder.watchAll()
      feeder.stopAll()

      feeder.feeds.forEach(function (feed) {
        expect(feed.id).to.be.null
      })
    })
  })
})
